@@ -200,19 +200,20 @@ mips_sde_frame_base_sniffer (const frame_info_ptr &this_frame)
     return NULL;
 }
 
-static void
-mips_sde_elf_osabi_sniff_abi_tag_sections (bfd *abfd, asection *sect,
-					   void *obj)
+static gdb_osabi
+mips_sde_elf_osabi_sniff_abi_tag_sections (bfd *abfd)
 {
-  enum gdb_osabi *os_ident_ptr = (enum gdb_osabi *) obj;
-  const char *name;
+  for (asection *sect : gdb_bfd_sections (abfd))
+    {
+      const char *name = bfd_section_name (sect);
 
-  name = bfd_section_name (sect);
+      /* The presence of a section with a ".sde" prefix is indicative
+	 of an SDE binary.  */
+      if (startswith (name, ".sde"))
+	return GDB_OSABI_SDE;
+    }
 
-  /* The presence of a section with a ".sde" prefix is indicative
-     of an SDE binary.  */
-  if (startswith (name, ".sde"))
-    *os_ident_ptr = GDB_OSABI_SDE;
+  return GDB_OSABI_UNKNOWN;
 }
 
 /* OSABI sniffer for MIPS SDE.  */
@@ -240,9 +241,7 @@ mips_sde_elf_osabi_sniffer (bfd *abfd)
 	 real OS in use we must look for OS notes that have been added.
 
 	 For SDE, we simply look for sections named with .sde as prefixes.  */
-      bfd_map_over_sections (abfd,
-			     mips_sde_elf_osabi_sniff_abi_tag_sections,
-			     &osabi);
+      osabi = mips_sde_elf_osabi_sniff_abi_tag_sections (abfd);
     }
   return osabi;
 }
